@@ -199,38 +199,38 @@ namespace seqan
         Pair<TSize> range;            // current SA interval of hits (unique node identifier)
         TSize        parentRight;    // right boundary of parent node's range (allows to go right)
 
-        SEQAN_HOST_DEVICE
+       
         VertexEsa() : range(0, 0), parentRight(0) {}
 
-        SEQAN_HOST_DEVICE
+       
         VertexEsa(MinimalCtor):
             range(0,0),
             parentRight(0) {}
 
-        SEQAN_HOST_DEVICE
+       
         VertexEsa(TSize otherRangeLeft, TSize otherRangeRight, TSize otherParentRight):
             range(Pair<TSize>(otherRangeLeft, otherRangeRight)),
             parentRight(otherParentRight) {}
 
-        SEQAN_HOST_DEVICE
+       
         VertexEsa(Pair<TSize> const &otherRange, TSize otherParentRight):
             range(otherRange),
             parentRight(otherParentRight) {}
 
-        SEQAN_HOST_DEVICE
+       
         VertexEsa(VertexEsa const &other):
             range(other.range),
             parentRight(other.parentRight) {}
     };
 
     template <typename TSize>
-    SEQAN_HOST_DEVICE inline bool operator==(VertexEsa<TSize> const &a, VertexEsa<TSize> const &b)
+    inline bool operator==(VertexEsa<TSize> const &a, VertexEsa<TSize> const &b)
     {
         return a.range == b.range;
     }
 
     template <typename TSize>
-    SEQAN_HOST_DEVICE inline bool operator!=(VertexEsa<TSize> const &a, VertexEsa<TSize> const &b)
+    inline bool operator!=(VertexEsa<TSize> const &a, VertexEsa<TSize> const &b)
     {
         return a.range != b.range;
     }
@@ -401,6 +401,18 @@ namespace seqan
         typename Fibre<Index, EsaBwt>::Type         bwt;        // burrows-wheeler table
         typename Cargo<Index>::Type                 cargo;        // user-defined cargo
 
+        /*!
+         * @fn IndexEsa::Index
+         * @brief Constructor
+         *
+         * @signature Index::Index();
+         * @signature Index::Index(index);
+         * @signature Index::Index(text);
+         *
+         * @param[in] index Other Index object to copy from.
+         * @param[in] text  The text to be indexed.
+         */
+
         Index() {}
 
         Index(Index &other):
@@ -435,7 +447,7 @@ namespace seqan
 //////////////////////////////////////////////////////////////////////////////
 
     template < typename TText, typename TSpec >
-    SEQAN_HOST_DEVICE inline void _indexRequireTopDownIteration(Index<TText, IndexEsa<TSpec> > &index)
+    inline void _indexRequireTopDownIteration(Index<TText, IndexEsa<TSpec> > &index)
     {
         indexRequire(index, EsaSA());
         indexRequire(index, EsaLcp());
